from setuptools import setup


setup(
    name='gename',
    version='0.0.7',
    description='Guess gender from first name.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Mikko Hellsing',
    author_email='mikko@sumsum.se',
    url='http://github.com/sorl/gename',
    packages=['gename'],
    include_package_data=True,
    zip_safe=False,
    license='ICS',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: ISC License (ISCL)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.7',
    ]
)



import sqlite3
import os


here = os.path.abspath(os.path.dirname(__file__))


class Gender:
    def __init__(self):
        self.conn = sqlite3.connect(os.path.join(here, 'names.db'))
        self.cur = self.conn.cursor()

    def speculate(self, name):
        self.cur.execute(
            'SELECT gender from name_gender WHERE name=?',
            (name.lower(),)
        )
        res = self.cur.fetchone()
        if res:
            return res[0]
        return 'U'
